@@ -3,35 +3,35 @@ NULL
 
 #' Compile a problem
 #'
-#' Compile a conservation planning \code{\link{problem}} into an
+#' Compile a conservation planning [problem()] into an
 #' (potentially mixed) integer linear programming problem.
 #'
-#' @param x \code{\link{ConservationProblem-class}} object.
+#' @param x [problem()] (i.e. [`ConservationProblem-class`]) object.
 #'
-#' @param compressed_formulation \code{logical} should the conservation problem
+#' @param compressed_formulation `logical` should the conservation problem
 #'   compiled into a compressed version of a planning problem?
-#'   If \code{TRUE} then the problem is expressed using the compressed
-#'   formulation. If \code{FALSE} then the problem is expressed using the
-#'   expanded formulation. If \code{NA}, then the compressed is used unless one
+#'   If `TRUE` then the problem is expressed using the compressed
+#'   formulation. If `FALSE` then the problem is expressed using the
+#'   expanded formulation. If `NA`, then the compressed is used unless one
 #'   of the constraints requires the expanded formulation. This argument
-#'   defaults to \code{NA}.
+#'   defaults to `NA`.
 #'
 #' @param ... not used.
 #'
 #' @details This function might be useful for those interested in understanding
-#'   how their conservation planning \code{\link{problem}} is expressed
+#'   how their conservation planning [problem()] is expressed
 #'   as a mathematical problem. However, if the problem just needs to
-#'   be solved, then the \code{\link{solve}} function should just be used.
+#'   be solved, then the [solve()] function should just be used.
 #'
-#'   \strong{Please note that in nearly all cases, the default argument to
-#'   \code{formulation} should be used}. The only situation where manually
-#'   setting the argument to \code{formulation} is desirable is during testing.
-#'   Manually setting the argument to \code{formulation} will at best
+#'   **Please note that in nearly all cases, the default argument to
+#'   `formulation` should be used**. The only situation where manually
+#'   setting the argument to `formulation` is desirable is during testing.
+#'   Manually setting the argument to `formulation` will at best
 #'   have no effect on the problem. At worst, it may result in
 #'   an error, a misspecified problem, or unnecessarily long
 #'   solve times.
 #'
-#' @return \code{\link{OptimizationProblem-class}} object.
+#' @return [`OptimizationProblem-class`] object.
 #'
 #' @examples
 #' # build minimal conservation problem
@@ -57,8 +57,8 @@ compile.ConservationProblem <- function(x, compressed_formulation = NA, ...) {
     is.na(compressed_formulation) ||
           assertthat::is.flag(compressed_formulation))
   # sanity checks
-  if (inherits(x$objective, c("MaximumUtilityObjective",
-                              "MaximumCoverageObjective")) &
+  if (inherits(x$objective,
+               c("MaximumUtilityObjective", "MaximumCoverageObjective")) &
       !is.Waiver(x$targets))
     warning(paste("ignoring targets since the specified objective",
                   "function doesn't use targets"))
@@ -116,6 +116,14 @@ compile.ConservationProblem <- function(x, compressed_formulation = NA, ...) {
   }
   # add penalties to optimization problem
   for (i in x$penalties$ids()) {
+    ## run sanity check
+    if (inherits(x$penalties[[i]], "FeatureWeights") &
+        inherits(x$objective, "MinimumSetObjective")) {
+      warning(paste("ignoring weights since the specified objective",
+                    "function doesn't use weights"))
+      next()
+    }
+    ## apply penalty if it makes sense to do so
     x$penalties[[i]]$calculate(x)
     x$penalties[[i]]$apply(op, x)
   }
