@@ -1,6 +1,7 @@
 context("add_feature_contiguity_constraints")
 
 test_that("compile (single zone)", {
+  # create data
   spp1_habitat <- raster::raster(matrix(c(
     5, 0, 5,
     0, 0, 0,
@@ -114,9 +115,9 @@ test_that("compile (single zone)", {
 
 test_that("solve (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
+  # create data
   spp1_habitat <- raster::raster(matrix(c(
     5, 0, 5,
     0, 0, 0,
@@ -349,9 +350,9 @@ test_that("compile (multiple zones)", {
 
 test_that("solve (multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
+  # create data
   spp1_z1 <- raster::raster(matrix(c(
     5, 0, 5,
     0, 0, 0,
