@@ -24,8 +24,7 @@ test_that("integer (compile, single zone)", {
 
 test_that("integer (solve, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_raster, sim_features)
@@ -70,8 +69,7 @@ test_that("logical (compile, single zone)", {
 
 test_that("logical (solve, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_raster, sim_features)
@@ -125,8 +123,7 @@ test_that("matrix (compile, multiple zones)", {
 
 test_that("matrix (solve, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_zones_stack, sim_features_zones)
@@ -199,8 +196,7 @@ test_that("character (compile, Spatial, single zone)", {
 
 test_that("character (solve, Spatial, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_polygons, sim_features)
@@ -268,8 +264,7 @@ test_that("character (compile, Spatial, multiple zones)", {
 
 test_that("character (solve, Spatial, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_zones_polygons, sim_features_zones)
@@ -296,8 +291,7 @@ test_that("character (solve, Spatial, multiple zones)", {
 
 test_that("character (solve, single zone, proportion decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_polygons, sim_features)
@@ -395,8 +389,7 @@ test_that("raster (compile, single zone)", {
 
 test_that("raster (solve, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_raster, sim_locked_in_raster, sim_features)
@@ -454,8 +447,7 @@ test_that("raster (compile, multiple zones)", {
 
 test_that("raster (solve, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_zones_stack, sim_features_zones)
@@ -529,8 +521,7 @@ test_that("spatial (compile, single zone)", {
 
 test_that("spatial (solve, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create problem
   data(sim_pu_polygons, sim_features)
