@@ -22,8 +22,7 @@ test_that("data.frame (compile, single zone)", {
 
 test_that("data.frame (solve, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create and solve problem
   data(sim_pu_polygons, sim_features)
@@ -76,8 +75,7 @@ test_that("data.frame (compile, multiple zones)", {
 
 test_that("data.frame (solve, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create and solve problem
   data(sim_pu_zones_polygons, sim_features_zones)
