@@ -19,8 +19,7 @@ test_that("compile", {
 
 test_that("solve (RasterLayer, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
@@ -47,8 +46,7 @@ test_that("solve (RasterLayer, single zone)", {
 
 test_that("solve (RasterStack, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_zones_stack, sim_features_zones)
@@ -76,8 +74,7 @@ test_that("solve (RasterStack, multiple zones)", {
 
 test_that("solve (SpatialPolygonsDataFrame, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons, sim_features)
@@ -101,8 +98,7 @@ test_that("solve (SpatialPolygonsDataFrame, single zone)", {
 
 test_that("solve (SpatialPolygonsDataFrame, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make data
   data(sim_pu_zones_polygons, sim_features_zones)
@@ -134,8 +130,7 @@ test_that("solve (SpatialPolygonsDataFrame, multiple zones)", {
 
 test_that("solve (numeric, single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons, sim_features)
@@ -166,8 +161,7 @@ test_that("solve (numeric, single zone)", {
 
 test_that("solve (matrix, multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   costs <- data.frame(id = seq_len(7),
@@ -211,8 +205,7 @@ test_that("solve (matrix, multiple zones)", {
 
 test_that("solve (no duplicates)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   set.seed(500)
@@ -241,8 +234,7 @@ test_that("solve (no duplicates)", {
 
 test_that("solve (parallel processing)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   set.seed(500)
