@@ -39,8 +39,7 @@ test_that("character (compile)", {
 
 test_that("character (solve)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make problem
   path <- system.file("extdata/input.dat", package = "prioritizr")
@@ -56,8 +55,7 @@ test_that("character (solve)", {
 
 test_that("character (solve, absolute INPUTDIR path)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # set up input.dat with absolute file paths
   path <- file.path(tempfile(fileext = ".dat"))
@@ -78,8 +76,7 @@ test_that("character (solve, absolute INPUTDIR path)", {
 
 test_that("character (solve, absolute file paths)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # set up input.dat with absolute file paths
   path <- file.path(tempfile(fileext = ".dat"))
@@ -178,8 +175,7 @@ test_that("data.frame (compile, no boundary penalties)", {
 
 test_that("data.frame (solve, boundary penalties)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make problem
   path <- system.file("extdata/input.dat", package = "prioritizr")
@@ -202,8 +198,7 @@ test_that("data.frame (solve, boundary penalties)", {
 
 test_that("data.frame (solve, no boundary penalties)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make problem
   path <- system.file("extdata/input.dat", package = "prioritizr")
