@@ -760,6 +760,250 @@ test_that("x=matrix, features=data.frame", {
   expect_error(x$feature_targets())
 })
 
+test_that("x=sf, features=RasterStack", {
+  # load data
+  data(sim_pu_polygons, sim_features)
+  sim_pu_polygons$cost[1:5] <- NA
+  # create problem
+  x <- problem(sf::st_as_sf(sim_pu_polygons), sim_features, "cost")
+  # verify that object can be printed
+  suppressMessages(print(x))
+  suppressMessages(x)
+  # tests for integer fields
+  expect_equal(x$feature_names(), names(sim_features))
+  expect_equal(x$zone_names(), "cost")
+  expect_equal(x$number_of_features(), raster::nlayers(sim_features))
+  expect_equal(x$number_of_planning_units(), sum(!is.na(sim_pu_polygons$cost)))
+  expect_equal(x$planning_unit_indices(), which(!is.na(sim_pu_polygons$cost)))
+  expect_equal(x$number_of_total_units(), nrow(sim_pu_polygons))
+  expect_equal(problem(sim_pu_polygons, sim_pu_raster,
+                       "cost")$number_of_features(), 1L)
+  # tests for planning_unit_costs field
+  expect_equivalent(x$planning_unit_costs(),
+                    matrix(sim_pu_polygons$cost[!is.na(sim_pu_polygons$cost)],
+                           ncol = 1))
+  expect_equal(colnames(x$planning_unit_costs()), "cost")
+  # tests for feature_abundances_in_planning_units field
+  expect_equivalent(x$feature_abundances_in_planning_units(),
+                    Matrix::rowSums(x$data$rij_matrix[[1]]))
+  expect_equal(colnames(x$feature_abundances_in_planning_units()),
+               "cost")
+  expect_equal(rownames(x$feature_abundances_in_planning_units()),
+               names(sim_features))
+  # tests for feature_abundances_in_total_units field
+  expect_equivalent(x$feature_abundances_in_total_units(),
+                    matrix(colSums(raster::extract(sim_features,
+                                                   sim_pu_polygons,
+                                                   "sum", na.rm = TRUE)),
+                           ncol = 1))
+  expect_equal(colnames(x$feature_abundances_in_total_units()),
+               "cost")
+  expect_equal(rownames(x$feature_abundances_in_total_units()),
+               names(sim_features))
+  # tests for rij_matrix field
+  expect_equivalent(x$data$rij_matrix,
+                    list(rij_matrix(sim_pu_polygons[
+                      !is.na(sim_pu_polygons[[1]]), ], sim_features)))
+  expect_equal(names(x$data$rij_matrix), "cost")
+  expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
+  # test that calling targets before they have been inititalized throws error
+  expect_error(x$feature_targets())
+})
+
+test_that("x=sf, features=ZonesRaster", {
+  # load data
+  data(sim_pu_zones_polygons, sim_features_zones)
+  sim_pu_zones_polygons[5, paste0("cost_", 1:3)] <- NA
+  sim_pu_zones_polygons[4, "cost_1"] <- NA
+  # create problem
+  x <- problem(sf::st_as_sf(sim_pu_zones_polygons), sim_features_zones,
+               paste0("cost_", 1:3))
+  # verify that object can be printed
+  suppressMessages(print(x))
+  suppressMessages(x)
+  # tests for integer fields
+  expect_equal(x$feature_names(), feature_names(sim_features_zones))
+  expect_equal(x$zone_names(), zone_names(sim_features_zones))
+  expect_equal(x$number_of_features(), raster::nlayers(sim_features_zones[[1]]))
+  expect_equal(x$number_of_planning_units(), nrow(sim_pu_zones_polygons) - 1)
+  expect_equal(x$planning_unit_indices(),
+               c(seq_len(4), seq(6, nrow(sim_pu_zones_polygons))))
+  expect_equal(x$number_of_total_units(), nrow(sim_pu_polygons))
+  # tests for planning_unit_costs field
+  expect_equivalent(x$planning_unit_costs(), as.matrix(
+    sim_pu_zones_polygons@data[-5, paste0("cost_", 1:3)]))
+  expect_equal(colnames(x$planning_unit_costs()),
+               zone_names(sim_features_zones))
+  # tests for feature_abundances_in_planning_units field
+  expect_equivalent(x$feature_abundances_in_planning_units(),
+    sapply(seq_along(x$data$rij_matrix), function(i) {
+      pos1 <- x$planning_unit_indices()
+      pos2 <- which(!is.na(sim_pu_zones_polygons@data[[paste0("cost_", i)]]))
+      pos3 <- match(pos2, pos1)
+      Matrix::rowSums(x$data$rij_matrix[[i]][, pos3, drop = FALSE])
+    }))
+  expect_equal(colnames(x$feature_abundances_in_planning_units()),
+               zone_names(sim_features_zones))
+  expect_equal(rownames(x$feature_abundances_in_planning_units()),
+               feature_names(sim_features_zones))
+  # tests for feature_abundances_in_total_units field
+  expect_equivalent(x$feature_abundances_in_total_units(),
+                    sapply(lapply(sim_features_zones, raster::extract,
+                                          sim_pu_zones_polygons, "sum",
+                                          na.rm = TRUE),
+                                   colSums, na.rm = TRUE))
+  expect_equal(colnames(x$feature_abundances_in_total_units()),
+               zone_names(sim_features_zones))
+  expect_equal(rownames(x$feature_abundances_in_total_units()),
+               feature_names(sim_features_zones))
+  # tests for rij_matrix field
+  expect_equivalent(x$data$rij_matrix,
+                    lapply(sim_features_zones, rij_matrix,
+                           x = sim_pu_zones_polygons[-5, ]))
+  expect_equal(names(x$data$rij_matrix), zone_names(sim_features_zones))
+  expect_equivalent(sapply(x$data$rij_matrix, rownames),
+               matrix(feature_names(sim_features_zones),
+                      ncol = number_of_zones(sim_features_zones),
+                      nrow = number_of_features(sim_features_zones)))
+  # test that calling targets before they have been inititalized throws error
+  expect_error(x$feature_targets())
+})
+
+test_that("x=sf, features=character", {
+  # simulate data
+  data(sim_pu_polygons)
+  sim_pu_polygons$cost[2] <- NA
+  sim_pu_polygons$spp1 <- runif(length(sim_pu_polygons))
+  sim_pu_polygons$spp2 <- c(NA, rpois(length(sim_pu_polygons) - 1, 5))
+  # create problem
+  x <- problem(sf::st_as_sf(sim_pu_polygons), c("spp1", "spp2"), "cost")
+  # verify that object can be printed
+  suppressMessages(print(x))
+  suppressMessages(x)
+  # tests for integer fields
+  expect_equal(x$feature_names(), c("spp1", "spp2"))
+  expect_equal(x$zone_names(), "cost")
+  expect_equal(x$number_of_features(), 2)
+  expect_equal(x$number_of_zones(), 1)
+  expect_equal(x$number_of_planning_units(), length(sim_pu_polygons) - 1)
+  expect_equal(x$planning_unit_indices(), c(1, seq(3, length(sim_pu_polygons))))
+  expect_equal(x$number_of_total_units(), length(sim_pu_polygons))
+  # tests for planning_unit_costs field
+  expect_equivalent(x$planning_unit_costs(),
+                    matrix(sim_pu_polygons$cost[-2], ncol = 1))
+  expect_equal(colnames(x$planning_unit_costs()), "cost")
+  # tests for feature_abundances_in_planning_units field
+  expect_equivalent(x$feature_abundances_in_planning_units(),
+                    matrix(colSums(sim_pu_polygons@data[-2, c("spp1", "spp2")],
+                                   na.rm = TRUE), ncol = 1))
+  expect_equal(colnames(x$feature_abundances_in_planning_units()), "cost")
+  expect_equal(rownames(x$feature_abundances_in_planning_units()),
+               c("spp1", "spp2"))
+  # tests for feature_abundances_in_total_units field
+  expect_equivalent(x$feature_abundances_in_total_units(),
+                    matrix(colSums(sim_pu_polygons@data[, c("spp1", "spp2")],
+                                   na.rm = TRUE), ncol = 1))
+  expect_equal(colnames(x$feature_abundances_in_total_units()), "cost")
+  expect_equal(rownames(x$feature_abundances_in_total_units()),
+               c("spp1", "spp2"))
+  # tests for rij_matrix field
+  rij <- Matrix::sparseMatrix(i = c(rep(1, length(sim_pu_polygons) - 1),
+                                    rep(2, length(sim_pu_polygons) - 2)),
+                              j = c(seq_len(length(sim_pu_polygons) - 1),
+                                    seq_len(length(sim_pu_polygons) - 1)[-1]),
+                              x = c(sim_pu_polygons$spp1[-2],
+                                    sim_pu_polygons$spp2[c(-1, -2)]),
+                              dims = c(2, length(sim_pu_polygons) - 1))
+  rij <- list(rij)
+  expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
+  expect_equal(names(x$data$rij_matrix), "cost")
+  expect_equal(rownames(x$data$rij_matrix[[1]]),  c("spp1", "spp2"))
+  # test that calling targets before they have been inititalized throws error
+  expect_error(x$feature_targets())
+})
+
+test_that("x=sf, features=ZonesCharacter", {
+  # simulate data
+  data(sim_pu_zones_polygons)
+  sim_pu_zones_polygons$cost_1[2] <- NA
+  sim_pu_zones_polygons[3, c("cost_1", "cost_2")] <- NA
+  sim_pu_zones_polygons$spp1_1 <- runif(length(sim_pu_zones_polygons))
+  sim_pu_zones_polygons$spp2_1 <- c(NA, rpois(length(sim_pu_zones_polygons) - 1,
+                                    5))
+  sim_pu_zones_polygons$spp1_2 <- runif(length(sim_pu_zones_polygons))
+  sim_pu_zones_polygons$spp2_2 <- runif(length(sim_pu_zones_polygons))
+  sim_pu_zones_polygons <- sim_pu_zones_polygons[1:5, ]
+  # create problem
+  x <- problem(sf::st_as_sf(sim_pu_zones_polygons),
+               zones(c("spp1_1", "spp2_1"), c("spp1_2", "spp2_2"),
+                     zone_names = c("z1", "z2"),
+                     feature_names = c("spp1", "spp2")),
+               c("cost_1", "cost_2"))
+  # verify that object can be printed
+  suppressMessages(print(x))
+  suppressMessages(x)
+  # tests for integer fields
+  expect_equal(x$feature_names(), c("spp1", "spp2"))
+  expect_equal(x$zone_names(), c("z1", "z2"))
+  expect_equal(x$number_of_features(), 2)
+  expect_equal(x$number_of_zones(), 2)
+  expect_equal(x$number_of_planning_units(), length(sim_pu_zones_polygons) - 1)
+  expect_equal(x$planning_unit_indices(),
+               c(c(1, 2), seq(4, length(sim_pu_zones_polygons))))
+  expect_equal(x$number_of_total_units(), length(sim_pu_zones_polygons))
+  # tests for planning_unit_costs field
+  expect_equivalent(x$planning_unit_costs(),
+                    as.matrix(sim_pu_zones_polygons@data[-3, c("cost_1",
+                                                               "cost_2")]))
+  expect_equal(colnames(x$planning_unit_costs()), c("z1", "z2"))
+  # tests for feature_abundances_in_planning_units field
+  expect_equivalent(
+    x$feature_abundances_in_planning_units(),
+    matrix(c(sum(sim_pu_zones_polygons$spp1_1[
+               !is.na(sim_pu_zones_polygons$cost_1)], na.rm = TRUE),
+             sum(sim_pu_zones_polygons$spp2_1[
+               !is.na(sim_pu_zones_polygons$cost_1)], na.rm = TRUE),
+             sum(sim_pu_zones_polygons$spp1_2[
+               !is.na(sim_pu_zones_polygons$cost_2)], na.rm = TRUE),
+             sum(sim_pu_zones_polygons$spp2_2[
+               !is.na(sim_pu_zones_polygons$cost_2)], na.rm = TRUE)),
+           ncol = 4))
+  expect_equal(colnames(x$feature_abundances_in_planning_units()),
+               c("z1", "z2"))
+  expect_equal(rownames(x$feature_abundances_in_planning_units()),
+               c("spp1", "spp2"))
+  # tests for feature_abundances_in_total_units field
+  expect_equivalent(x$feature_abundances_in_total_units(),
+    matrix(colSums(sim_pu_zones_polygons@data[,
+    c("spp1_1", "spp2_1", "spp1_2", "spp2_2")], na.rm = TRUE), ncol = 2))
+  expect_equal(colnames(x$feature_abundances_in_total_units()),
+               c("z1", "z2"))
+  expect_equal(rownames(x$feature_abundances_in_total_units()),
+               c("spp1", "spp2"))
+  # tests for rij_matrix field
+  r1 <- Matrix::sparseMatrix(i = c(rep(1, length(sim_pu_zones_polygons) - 1),
+                                   rep(2, length(sim_pu_zones_polygons) - 2)),
+                             j = c(seq_len(length(sim_pu_zones_polygons) - 1),
+                                   seq_len(length(sim_pu_zones_polygons) -
+                                           1)[-1]),
+                             x = c(sim_pu_zones_polygons$spp1_1[-3],
+                                   sim_pu_zones_polygons$spp2_1[c(-1, -3)]),
+                             dims = c(2, length(sim_pu_zones_polygons) - 1))
+  r2 <- Matrix::sparseMatrix(i = c(rep(1, length(sim_pu_zones_polygons) - 1),
+                                   rep(2, length(sim_pu_zones_polygons) - 1)),
+                             j = c(seq_len(length(sim_pu_zones_polygons) - 1),
+                                   seq_len(length(sim_pu_zones_polygons) - 1)),
+                             x = c(sim_pu_zones_polygons$spp1_2[-3],
+                                   sim_pu_zones_polygons$spp2_2[-3]),
+                             dims = c(2, length(sim_pu_zones_polygons) - 1))
+  rij <- list(r1, r2)
+  expect_equal(names(x$data$rij_matrix), c("z1", "z2"))
+  expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
+  expect_true(all(x$data$rij_matrix[[2]] == rij[[2]]))
+  # test that calling targets before they have been inititalized throws error
+  expect_error(x$feature_targets())
+})
+
 test_that("invalid problem inputs", {
   # check that errors are thrown if invalid arguments
   data(sim_pu_polygons, sim_pu_lines, sim_pu_points, sim_pu_raster,
@@ -823,7 +1067,7 @@ test_that("get parameter methods", {
   id5 <- x$penalties[[x$penalties$ids()[1]]]$parameters$find("penalty")
   expect_equal(x$get_objective_parameter(as.Id(id1)), 400)
   expect_equal(x$get_constraint_parameter(as.Id(id3)),
-               tibble::tibble(pu = 1, zone = factor("layer"), status = 1))
+               tibble::tibble(pu = 1, zone = "layer", status = 1))
   expect_equal(x$get_portfolio_parameter(as.Id(id4)), 100)
   expect_equal(x$get_penalty_parameter(as.Id(id5)), 200)
   skip_if_not(any_solvers_installed())
@@ -847,18 +1091,18 @@ test_that("set parameter methods", {
   id5 <- x$penalties[[x$penalties$ids()[1]]]$parameters$find("penalty")
   expect_equal(x$get_objective_parameter(as.Id(id1)), 400)
   expect_equal(x$get_constraint_parameter(as.Id(id3)),
-               tibble::tibble(pu = 1, zone = factor("layer"), status = 1))
+               tibble::tibble(pu = 1, zone = "layer", status = 1))
   expect_equal(x$get_portfolio_parameter(as.Id(id4)), 100)
   expect_equal(x$get_penalty_parameter(as.Id(id5)), 200)
   x$set_objective_parameter(as.Id(id1), 90)
   x$set_constraint_parameter(as.Id(id3),
-                             tibble::tibble(pu = 2, zone = factor("layer"),
+                             tibble::tibble(pu = 2, zone = "layer",
                              status = 1))
   x$set_portfolio_parameter(as.Id(id4), 300L)
   x$set_penalty_parameter(as.Id(id5), 500)
   expect_equal(x$get_objective_parameter(as.Id(id1)), 90)
   expect_equal(x$get_constraint_parameter(as.Id(id3)),
-               tibble::tibble(pu = 2, zone = factor("layer"), status = 1))
+               tibble::tibble(pu = 2, zone = "layer", status = 1))
   expect_equal(x$get_portfolio_parameter(as.Id(id4)), 300)
   expect_equal(x$get_penalty_parameter(as.Id(id5)), 500)
   skip_if_not(any_solvers_installed())
@@ -894,6 +1138,7 @@ test_that("render parameter methods", {
 })
 
 test_that("render all parameters methods", {
+  skip_if_not_installed("rhandsontable")
   data(sim_pu_raster, sim_features)
   x <- problem(sim_pu_raster, sim_features) %>%
        add_min_set_objective() %>%
