@@ -2,8 +2,7 @@ context("replacement_cost")
 
 test_that("numeric", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(4),
@@ -30,8 +29,7 @@ test_that("numeric", {
 
 test_that("matrix (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(4),
@@ -60,8 +58,7 @@ test_that("matrix (single zone)", {
 
 test_that("matrix (single zone, rescale = TRUE)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(4),
@@ -90,8 +87,7 @@ test_that("matrix (single zone, rescale = TRUE)", {
 
 test_that("matrix (multiple zones)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(8),
@@ -124,8 +120,7 @@ test_that("matrix (multiple zones)", {
 
 test_that("matrix (multiple zones, rescale = TRUE)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(8),
@@ -159,8 +154,7 @@ test_that("matrix (multiple zones, rescale = TRUE)", {
 
 test_that("data.frame (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(4),
@@ -186,8 +180,7 @@ test_that("data.frame (single zone)", {
 
 test_that("data.frame (multiple zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- data.frame(id = seq_len(8),
@@ -220,8 +213,7 @@ test_that("data.frame (multiple zone)", {
 
 test_that("Spatial (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons)
@@ -249,8 +241,7 @@ test_that("Spatial (single zone)", {
 
 test_that("Spatial (multiple zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons)
@@ -286,8 +277,7 @@ test_that("Spatial (multiple zone)", {
 
 test_that("sf (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons)
@@ -316,8 +306,7 @@ test_that("sf (single zone)", {
 
 test_that("sf (multiple zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   data(sim_pu_polygons)
@@ -354,8 +343,7 @@ test_that("sf (multiple zone)", {
 
 test_that("Raster (single zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- raster::raster(matrix(c(10, 2, NA, 3), nrow = 1))
@@ -380,8 +368,7 @@ test_that("Raster (single zone)", {
 
 test_that("Raster (multiple zone)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # create data
   pu <- raster::stack(
@@ -417,8 +404,7 @@ test_that("Raster (multiple zone)", {
 
 test_that("Raster (multiple threads)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # load data
   data(sim_pu_raster, sim_features)
