@@ -2,8 +2,7 @@ context("solvers")
 
 test_that("add_default_solver (raster cost data)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make data
   data(sim_pu_raster, sim_features)
@@ -22,8 +21,7 @@ test_that("add_default_solver (raster cost data)", {
 
 test_that("add_default_solver (spatial cost data)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   # make data
   data(sim_pu_polygons, sim_features)
@@ -43,8 +41,7 @@ test_that("add_default_solver (spatial cost data)", {
 
 test_that("add_rsymphony_solver (binary decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("Rsymphony")
   # make data
@@ -65,8 +62,7 @@ test_that("add_rsymphony_solver (binary decisions)", {
 
 test_that("add_rsymphony_solver (proportion decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("Rsymphony")
   # make data
@@ -90,8 +86,7 @@ test_that("add_rsymphony_solver (proportion decisions)", {
 
 test_that("add_rsymphony_solver (proportion decisions, floating point)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("Rsymphony")
   skip_if_not_installed("prioritizrdata")
@@ -134,8 +129,7 @@ test_that("add_rsymphony_solver (variable bounds methods)", {
 
 test_that("add_rsymphony_solver (mix of binary and continuous variables)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not_installed("Rsymphony")
   # make data
   b <- raster::cellStats(sim_pu_raster, "sum") * 0.2
@@ -153,10 +147,34 @@ test_that("add_rsymphony_solver (mix of binary and continuous variables)", {
                                     tolerance = 1e-5, stopiffalse = FALSE))
 })
 
+test_that("add_rsymphony_solver (correct solution)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not_installed("Rsymphony")
+  # create data
+  cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
+  locked_in <- 2
+  locked_out <- 1
+  features <- raster::stack(raster::raster(matrix(c(2, 1, 1, 0), ncol = 4)),
+                            raster::raster(matrix(c(10, 10, 10, 10), ncol = 4)))
+  # create problem
+  p <- problem(cost, features) %>%
+       add_min_set_objective() %>%
+       add_absolute_targets(c(2, 10)) %>%
+       add_locked_in_constraints(locked_in) %>%
+       add_locked_out_constraints(locked_out) %>%
+       add_rsymphony_solver(gap = 0, verbose = FALSE)
+  # solve problem
+  s1 <- solve(p)
+  s2 <- solve(p)
+  # test for correct solution
+  expect_equal(raster::values(s1), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), raster::values(s2))
+})
+
 test_that("add_lpsymphony_solver (binary decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("lpsymphony")
   skip_on_os("linux") # lpsymphony package crashes unpredictably on Ubuntu 16.04
@@ -178,8 +196,7 @@ test_that("add_lpsymphony_solver (binary decisions)", {
 
 test_that("add_lpsymphony_solver (proportion decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("lpsymphony")
   skip_on_os("linux") # lpsymphony package crashes unpredictably on Ubuntu 16.04
@@ -204,8 +221,7 @@ test_that("add_lpsymphony_solver (proportion decisions)", {
 
 test_that("add_lpsymphony_solver (proportion decisions, floating point)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("lpsymphony")
   skip_if_not_installed("prioritizrdata")
@@ -249,8 +265,7 @@ test_that("add_lpsymphony_solver (variable bounds methods)", {
 
 test_that("add_lpsymphony_solver (mix of binary and continuous variables)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not_installed("lpsymphony")
   skip_on_os("linux") # lpsymphony package crashes unpredictably on Ubuntu 16.04
   # make data
@@ -269,10 +284,35 @@ test_that("add_lpsymphony_solver (mix of binary and continuous variables)", {
                                     tolerance = 1e-5, stopiffalse = FALSE))
 })
 
+test_that("add_lpsymphony_solver (correct solution)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not_installed("lpsymphony")
+  skip_on_os("linux") # lpsymphony package crashes unpredictably on Ubuntu 16.04
+  # create data
+  cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
+  locked_in <- 2
+  locked_out <- 1
+  features <- raster::stack(raster::raster(matrix(c(2, 1, 1, 0), ncol = 4)),
+                            raster::raster(matrix(c(10, 10, 10, 10), ncol = 4)))
+  # create problem
+  p <- problem(cost, features) %>%
+       add_min_set_objective() %>%
+       add_absolute_targets(c(2, 10)) %>%
+       add_locked_in_constraints(locked_in) %>%
+       add_locked_out_constraints(locked_out) %>%
+       add_lpsymphony_solver(gap = 0, verbose = FALSE)
+  # solve problem
+  s1 <- solve(p)
+  s2 <- solve(p)
+  # test for correct solution
+  expect_equal(raster::values(s1), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), raster::values(s2))
+})
+
 test_that("add_gurobi_solver (binary decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("gurobi")
   # make data
@@ -300,8 +340,7 @@ test_that("add_gurobi_solver (binary decisions)", {
 
 test_that("add_gurobi_solver (proportion decisions)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("gurobi")
   # make data
@@ -325,8 +364,7 @@ test_that("add_gurobi_solver (proportion decisions)", {
 
 test_that("add_gurobi_solver (proportion decisions, floating point)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not(any_solvers_installed())
   skip_if_not_installed("gurobi")
   skip_if_not_installed("prioritizrdata")
@@ -369,8 +407,7 @@ test_that("add_gurobi_solver (variable bounds methods)", {
 
 test_that("add_gurobi_solver (mix of binary and continuous variables)", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
   skip_if_not_installed("gurobi")
   # make data
   b <- raster::cellStats(sim_pu_raster, "sum") * 0.2
@@ -387,3 +424,168 @@ test_that("add_gurobi_solver (mix of binary and continuous variables)", {
   expect_true(raster::compareRaster(sim_pu_raster, s, res = TRUE, crs = TRUE,
                                     tolerance = 1e-5, stopiffalse = FALSE))
 })
+
+test_that("add_gurobi_solver (correct solution)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not_installed("gurobi")
+  # create data
+  cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
+  locked_in <- 2
+  locked_out <- 1
+  features <- raster::stack(raster::raster(matrix(c(2, 1, 1, 0), ncol = 4)),
+                            raster::raster(matrix(c(10, 10, 10, 10), ncol = 4)))
+  # create problem
+  p <- problem(cost, features) %>%
+       add_min_set_objective() %>%
+       add_absolute_targets(c(2, 10)) %>%
+       add_locked_in_constraints(locked_in) %>%
+       add_locked_out_constraints(locked_out) %>%
+       add_gurobi_solver(gap = 0, verbose = FALSE)
+  # solve problem
+  s1 <- solve(p)
+  s2 <- solve(p)
+  # test for correct solution
+  expect_equal(raster::values(s1), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), raster::values(s2))
+})
+
+test_that("add_cplex_solver (binary decisions)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not(any_solvers_installed())
+  skip_if_not_installed("cplexAPI")
+  # make data
+  data(sim_pu_raster, sim_features)
+  p1 <- problem(sim_pu_raster, sim_features) %>%
+        add_min_set_objective() %>%
+        add_relative_targets(0.1) %>%
+        add_binary_decisions() %>%
+        add_cplex_solver(time_limit = 5, verbose = FALSE)
+  p2 <- problem(sim_pu_raster, sim_features) %>%
+        add_min_set_objective() %>%
+        add_relative_targets(0.1) %>%
+        add_binary_decisions() %>%
+        add_cplex_solver(time_limit = 5, verbose = FALSE)
+  s1 <- solve(p1)
+  s2 <- solve(p2)
+  # check that solution has correct properties
+  expect_is(s1, "Raster")
+  expect_equal(raster::nlayers(s1), 1)
+  expect_equal(sort(unique(raster::getValues(s1))), c(0, 1))
+  expect_true(raster::compareRaster(sim_pu_raster, s1, res = TRUE, crs = TRUE,
+                                    tolerance = 1e-5, stopiffalse = FALSE))
+  expect_equal(raster::getValues(s1), raster::getValues(s2))
+})
+
+test_that("add_cplex_solver (proportion decisions)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not(any_solvers_installed())
+  skip_if_not_installed("cplexAPI")
+  # make data
+  data(sim_pu_raster, sim_features)
+  p <- problem(sim_pu_raster, sim_features) %>%
+       add_min_set_objective() %>%
+       add_relative_targets(0.1) %>%
+       add_proportion_decisions() %>%
+       add_cplex_solver(gap = 0, verbose = FALSE)
+  s <- solve(p)
+  # check that solution has correct properties
+  expect_is(s, "Raster")
+  expect_equal(raster::nlayers(s), 1)
+  expect_gte(min(raster::getValues(s), na.rm = TRUE), 0)
+  expect_lte(max(raster::getValues(s), na.rm = TRUE), 1)
+  expect_gt(max(raster::getValues(s) - round(raster::getValues(s)),
+              na.rm = TRUE), 0.01)
+  expect_true(raster::compareRaster(sim_pu_raster, s, res = TRUE, crs = TRUE,
+                                    tolerance = 1e-5, stopiffalse = FALSE))
+})
+
+test_that("add_cplex_solver (proportion decisions, floating point)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not(any_solvers_installed())
+  skip_if_not_installed("cplexAPI")
+  skip_if_not_installed("prioritizrdata")
+  # make data
+  data(tas_pu, tas_features, package = "prioritizrdata")
+  tas_pu <- tas_pu[1:10, ]
+  p <- problem(tas_pu, tas_features, cost = "cost") %>%
+       add_min_set_objective() %>%
+       add_relative_targets(1) %>%
+       add_proportion_decisions() %>%
+       add_cplex_solver(gap = 0, verbose = FALSE)
+  s <- solve(p)
+  # check that solution has correct properties
+  expect_true(inherits(s, "SpatialPolygonsDataFrame"))
+  expect_true("solution_1" %in% names(s@data))
+  expect_equal(nrow(s), nrow(tas_pu))
+  expect_is(s$solution_1, "numeric")
+  expect_gte(min(s$solution_1), 0)
+  expect_lte(max(s$solution_1), 1)
+})
+
+test_that("add_cplex_solver (variable bounds methods)", {
+  skip_if_not_installed("cplexAPI")
+  # make data
+  data(sim_pu_raster, sim_features)
+  p <- problem(sim_pu_raster, sim_features) %>%
+       add_min_set_objective() %>%
+       add_relative_targets(0.1) %>%
+       add_binary_decisions() %>%
+       add_cplex_solver(verbose = TRUE)
+  p$solver$calculate(compile.ConservationProblem(p))
+  p$solver$set_variable_ub(1, 0)
+  p$solver$set_variable_lb(2, 1)
+  # check that  solution has correct properties
+  expect_equal(p$solver$data$model$ub,
+               replace(rep(1, p$number_of_planning_units()), 1, 0))
+  expect_equal(p$solver$data$model$lb,
+               replace(rep(0, p$number_of_planning_units()), 2, 1))
+})
+
+test_that("add_cplex_solver (mix of binary and continuous variables)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not_installed("cplexAPI")
+  # make data
+  b <- raster::cellStats(sim_pu_raster, "sum") * 0.2
+  data(sim_pu_raster, sim_features)
+  p <- problem(sim_pu_raster, sim_features) %>%
+       add_max_utility_objective(b) %>%
+       add_binary_decisions() %>%
+       add_cplex_solver(verbose = FALSE)
+  s <- solve(p)
+  # check that solution has correct properties
+  expect_true(inherits(s, "Raster"))
+  expect_equal(raster::nlayers(s), 1)
+  expect_equal(sort(unique(raster::getValues(s))), c(0, 1))
+  expect_true(raster::compareRaster(sim_pu_raster, s, res = TRUE, crs = TRUE,
+                                    tolerance = 1e-5, stopiffalse = FALSE))
+})
+
+test_that("add_cplex_solver (correct solution)", {
+  skip_on_cran()
+  skip_on_ci()
+  skip_if_not_installed("cplexAPI")
+  # create data
+  cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
+  locked_in <- 2
+  locked_out <- 1
+  features <- raster::stack(raster::raster(matrix(c(2, 1, 1, 0), ncol = 4)),
+                            raster::raster(matrix(c(10, 10, 10, 10), ncol = 4)))
+  # create problem
+  p <- problem(cost, features) %>%
+       add_min_set_objective() %>%
+       add_absolute_targets(c(2, 10)) %>%
+       add_locked_in_constraints(locked_in) %>%
+       add_locked_out_constraints(locked_out) %>%
+       add_cplex_solver(gap = 0, verbose = FALSE)
+  # solve problem
+  s1 <- solve(p)
+  s2 <- solve(p)
+  # test for correct solution
+  expect_equal(raster::values(s1), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), raster::values(s2))
+})
